@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.25.0";
+our $VERSION = "v6.26.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 99 of the 100+ operators in rxjs are implemented in this module.
+Currently 100 of the more than 100 operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -1142,6 +1142,7 @@ L<https://rxjs.dev/api/operators/skipLast>
 
     # (pause 3 seconds) 0, 1, 2, 3, 4, 5, 6, 7, complete
     rx_interval(1)->pipe(
+        op_take(10),
         op_skip_last(2),
     )->subscribe($observer);
 
@@ -1297,6 +1298,15 @@ L<https://rxjs.dev/api/operators/timeInterval>
         op_time_interval(),
     )->subscribe($observer);
 
+=item op_timeout
+
+L<https://rxjs.dev/api/operators/timeout>
+
+    # 0, error: Timeout has occurred
+    rx_timer(0.5, 2)->pipe(
+        op_timeout(1),
+    )->subscribe($observer);
+
 =item op_timestamp
 
 L<https://rxjs.dev/api/operators/timestamp>
