@@ -5,6 +5,7 @@ use warnings;
 use RxPerl::Operators::Creation qw/
     rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest rx_concat
     rx_throw_error rx_zip rx_merge rx_on_error_resume_next rx_race rx_timer
+    rx_behavior_subject
 /;
 use RxPerl::ConnectableObservable;
 use RxPerl::Utils qw/ get_timer_subs /;
@@ -24,11 +25,11 @@ our @EXPORT_OK = qw/
     op_on_error_resume_next_with op_pairwise op_pluck op_race_with op_reduce op_ref_count op_repeat op_retry op_sample
     op_sample_time op_scan op_share op_single op_skip op_skip_last op_skip_until op_skip_while op_start_with
     op_switch_all op_switch_map op_take op_take_last op_take_until op_take_while op_tap op_throttle op_throttle_time
-    op_throw_if_empty op_time_interval op_timestamp op_to_array op_with_latest_from op_zip_with
+    op_throw_if_empty op_time_interval op_timeout op_timestamp op_to_array op_with_latest_from op_zip_with
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.25.0";
+our $VERSION = "v6.26.0";
 
 sub op_audit {
     my ($duration_selector) = @_;
@@ -2251,6 +2252,46 @@ sub op_time_interval {
     };
 }
 
+sub op_timeout {
+    my ($duration) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $subject = rx_behavior_subject->new(1);
+            my $s_s = $subject->pipe(
+                op_switch_map(sub { rx_timer($duration) }),
+            )->subscribe(sub {
+                $subscriber->{error}->('Timeout has occurred') if defined $subscriber->{error};
+            });
+
+            my $own_subscription = RxPerl::Subscription->new;
+            $subscriber->subscription->add($own_subscription, $s_s);
+
+            my $own_subscriber = {
+                new_subscription => $own_subscription,
+                next     => sub {
+                    $subject->{next}->(1) if defined $subject->{next};
+                    $subscriber->{next}->(@_) if defined $subscriber->{next};
+                },
+                error    => sub {
+                    $subscriber->{error}->(@_) if defined $subscriber->{error};
+                },
+                complete => sub {
+                    $subscriber->{complete}->() if defined $subscriber->{complete};
+                }
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_timestamp {
     return op_map(sub {
         return {
